# Generated from NmrStar2CSParser.g4 by ANTLR 4.13.0
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,23,84,2,0,7,0,2,1,7,1,2,2,7,2,2,3,7,3,2,4,7,4,2,5,7,5,2,6,7,
        6,2,7,7,7,1,0,3,0,18,8,0,1,0,1,0,1,0,5,0,23,8,0,10,0,12,0,26,9,0,
        1,0,1,0,1,1,1,1,1,1,4,1,33,8,1,11,1,12,1,34,1,1,4,1,38,8,1,11,1,
        12,1,39,1,1,1,1,3,1,44,8,1,1,2,1,2,1,2,1,3,4,3,50,8,3,11,3,12,3,
        51,1,3,1,3,1,4,1,4,1,4,4,4,59,8,4,11,4,12,4,60,1,4,4,4,64,8,4,11,
        4,12,4,65,1,4,1,4,3,4,70,8,4,1,5,1,5,1,5,1,6,4,6,76,8,6,11,6,12,
        6,77,1,6,1,6,1,7,1,7,1,7,0,0,8,0,2,4,6,8,10,12,14,0,4,1,1,21,21,
        1,0,3,4,1,0,3,11,2,0,12,13,17,19,87,0,17,1,0,0,0,2,29,1,0,0,0,4,
        45,1,0,0,0,6,49,1,0,0,0,8,55,1,0,0,0,10,71,1,0,0,0,12,75,1,0,0,0,
        14,81,1,0,0,0,16,18,5,21,0,0,17,16,1,0,0,0,17,18,1,0,0,0,18,24,1,
        0,0,0,19,23,3,2,1,0,20,23,3,8,4,0,21,23,5,21,0,0,22,19,1,0,0,0,22,
        20,1,0,0,0,22,21,1,0,0,0,23,26,1,0,0,0,24,22,1,0,0,0,24,25,1,0,0,
        0,25,27,1,0,0,0,26,24,1,0,0,0,27,28,5,0,0,1,28,1,1,0,0,0,29,30,5,
        1,0,0,30,32,5,21,0,0,31,33,3,4,2,0,32,31,1,0,0,0,33,34,1,0,0,0,34,
        32,1,0,0,0,34,35,1,0,0,0,35,37,1,0,0,0,36,38,3,6,3,0,37,36,1,0,0,
        0,38,39,1,0,0,0,39,37,1,0,0,0,39,40,1,0,0,0,40,41,1,0,0,0,41,43,
        5,2,0,0,42,44,7,0,0,0,43,42,1,0,0,0,43,44,1,0,0,0,44,3,1,0,0,0,45,
        46,7,1,0,0,46,47,5,21,0,0,47,5,1,0,0,0,48,50,3,14,7,0,49,48,1,0,
        0,0,50,51,1,0,0,0,51,49,1,0,0,0,51,52,1,0,0,0,52,53,1,0,0,0,53,54,
        5,21,0,0,54,7,1,0,0,0,55,56,5,1,0,0,56,58,5,21,0,0,57,59,3,10,5,
        0,58,57,1,0,0,0,59,60,1,0,0,0,60,58,1,0,0,0,60,61,1,0,0,0,61,63,
        1,0,0,0,62,64,3,12,6,0,63,62,1,0,0,0,64,65,1,0,0,0,65,63,1,0,0,0,
        65,66,1,0,0,0,66,67,1,0,0,0,67,69,5,2,0,0,68,70,7,0,0,0,69,68,1,
        0,0,0,69,70,1,0,0,0,70,9,1,0,0,0,71,72,7,2,0,0,72,73,5,21,0,0,73,
        11,1,0,0,0,74,76,3,14,7,0,75,74,1,0,0,0,76,77,1,0,0,0,77,75,1,0,
        0,0,77,78,1,0,0,0,78,79,1,0,0,0,79,80,5,21,0,0,80,13,1,0,0,0,81,
        82,7,3,0,0,82,15,1,0,0,0,11,17,22,24,34,39,43,51,60,65,69,77
    ]

class NmrStar2CSParser ( Parser ):

    grammarFileName = "NmrStar2CSParser.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "'loop_'", "'stop_'", "'_Residue_seq_code'", 
                     "'_Residue_label'", "'_Atom_shift_assign_ID'", "'_Residue_author_seq_code'", 
                     "'_Atom_name'", "'_Atom_type'", "'_Chem_shift_value'", 
                     "'_Chem_shift_value_error'", "'_Chem_shift_ambiguity_code'" ]

    symbolicNames = [ "<INVALID>", "Loop", "Stop", "Residue_seq_code", "Residue_label", 
                      "Atom_shift_assign_ID", "Residue_author_seq_code", 
                      "Atom_name", "Atom_type", "Chem_shift_value", "Chem_shift_value_error", 
                      "Chem_shift_ambiguity_code", "Integer", "Float", "SHARP_COMMENT", 
                      "EXCLM_COMMENT", "SMCLN_COMMENT", "Simple_name", "Double_quote_string", 
                      "Single_quote_string", "SPACE", "RETURN", "SECTION_COMMENT", 
                      "LINE_COMMENT" ]

    RULE_nmrstar2_cs = 0
    RULE_seq_loop = 1
    RULE_seq_tags = 2
    RULE_seq_data = 3
    RULE_cs_loop = 4
    RULE_cs_tags = 5
    RULE_cs_data = 6
    RULE_any = 7

    ruleNames =  [ "nmrstar2_cs", "seq_loop", "seq_tags", "seq_data", "cs_loop", 
                   "cs_tags", "cs_data", "any" ]

    EOF = Token.EOF
    Loop=1
    Stop=2
    Residue_seq_code=3
    Residue_label=4
    Atom_shift_assign_ID=5
    Residue_author_seq_code=6
    Atom_name=7
    Atom_type=8
    Chem_shift_value=9
    Chem_shift_value_error=10
    Chem_shift_ambiguity_code=11
    Integer=12
    Float=13
    SHARP_COMMENT=14
    EXCLM_COMMENT=15
    SMCLN_COMMENT=16
    Simple_name=17
    Double_quote_string=18
    Single_quote_string=19
    SPACE=20
    RETURN=21
    SECTION_COMMENT=22
    LINE_COMMENT=23

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.13.0")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class Nmrstar2_csContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EOF(self):
            return self.getToken(NmrStar2CSParser.EOF, 0)

        def RETURN(self, i:int=None):
            if i is None:
                return self.getTokens(NmrStar2CSParser.RETURN)
            else:
                return self.getToken(NmrStar2CSParser.RETURN, i)

        def seq_loop(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrStar2CSParser.Seq_loopContext)
            else:
                return self.getTypedRuleContext(NmrStar2CSParser.Seq_loopContext,i)


        def cs_loop(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrStar2CSParser.Cs_loopContext)
            else:
                return self.getTypedRuleContext(NmrStar2CSParser.Cs_loopContext,i)


        def getRuleIndex(self):
            return NmrStar2CSParser.RULE_nmrstar2_cs

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNmrstar2_cs" ):
                listener.enterNmrstar2_cs(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNmrstar2_cs" ):
                listener.exitNmrstar2_cs(self)




    def nmrstar2_cs(self):

        localctx = NmrStar2CSParser.Nmrstar2_csContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_nmrstar2_cs)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 17
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,0,self._ctx)
            if la_ == 1:
                self.state = 16
                self.match(NmrStar2CSParser.RETURN)


            self.state = 24
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==1 or _la==21:
                self.state = 22
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,1,self._ctx)
                if la_ == 1:
                    self.state = 19
                    self.seq_loop()
                    pass

                elif la_ == 2:
                    self.state = 20
                    self.cs_loop()
                    pass

                elif la_ == 3:
                    self.state = 21
                    self.match(NmrStar2CSParser.RETURN)
                    pass


                self.state = 26
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 27
            self.match(NmrStar2CSParser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Seq_loopContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Loop(self):
            return self.getToken(NmrStar2CSParser.Loop, 0)

        def RETURN(self, i:int=None):
            if i is None:
                return self.getTokens(NmrStar2CSParser.RETURN)
            else:
                return self.getToken(NmrStar2CSParser.RETURN, i)

        def Stop(self):
            return self.getToken(NmrStar2CSParser.Stop, 0)

        def seq_tags(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrStar2CSParser.Seq_tagsContext)
            else:
                return self.getTypedRuleContext(NmrStar2CSParser.Seq_tagsContext,i)


        def seq_data(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrStar2CSParser.Seq_dataContext)
            else:
                return self.getTypedRuleContext(NmrStar2CSParser.Seq_dataContext,i)


        def EOF(self):
            return self.getToken(NmrStar2CSParser.EOF, 0)

        def getRuleIndex(self):
            return NmrStar2CSParser.RULE_seq_loop

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSeq_loop" ):
                listener.enterSeq_loop(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSeq_loop" ):
                listener.exitSeq_loop(self)




    def seq_loop(self):

        localctx = NmrStar2CSParser.Seq_loopContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_seq_loop)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 29
            self.match(NmrStar2CSParser.Loop)
            self.state = 30
            self.match(NmrStar2CSParser.RETURN)
            self.state = 32 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 31
                self.seq_tags()
                self.state = 34 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==3 or _la==4):
                    break

            self.state = 37 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 36
                self.seq_data()
                self.state = 39 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & 929792) != 0)):
                    break

            self.state = 41
            self.match(NmrStar2CSParser.Stop)
            self.state = 43
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,5,self._ctx)
            if la_ == 1:
                self.state = 42
                _la = self._input.LA(1)
                if not(_la==-1 or _la==21):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Seq_tagsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def RETURN(self):
            return self.getToken(NmrStar2CSParser.RETURN, 0)

        def Residue_seq_code(self):
            return self.getToken(NmrStar2CSParser.Residue_seq_code, 0)

        def Residue_label(self):
            return self.getToken(NmrStar2CSParser.Residue_label, 0)

        def getRuleIndex(self):
            return NmrStar2CSParser.RULE_seq_tags

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSeq_tags" ):
                listener.enterSeq_tags(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSeq_tags" ):
                listener.exitSeq_tags(self)




    def seq_tags(self):

        localctx = NmrStar2CSParser.Seq_tagsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_seq_tags)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 45
            _la = self._input.LA(1)
            if not(_la==3 or _la==4):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 46
            self.match(NmrStar2CSParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Seq_dataContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def RETURN(self):
            return self.getToken(NmrStar2CSParser.RETURN, 0)

        def any_(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrStar2CSParser.AnyContext)
            else:
                return self.getTypedRuleContext(NmrStar2CSParser.AnyContext,i)


        def getRuleIndex(self):
            return NmrStar2CSParser.RULE_seq_data

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterSeq_data" ):
                listener.enterSeq_data(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitSeq_data" ):
                listener.exitSeq_data(self)




    def seq_data(self):

        localctx = NmrStar2CSParser.Seq_dataContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_seq_data)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 49 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 48
                self.any_()
                self.state = 51 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & 929792) != 0)):
                    break

            self.state = 53
            self.match(NmrStar2CSParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Cs_loopContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Loop(self):
            return self.getToken(NmrStar2CSParser.Loop, 0)

        def RETURN(self, i:int=None):
            if i is None:
                return self.getTokens(NmrStar2CSParser.RETURN)
            else:
                return self.getToken(NmrStar2CSParser.RETURN, i)

        def Stop(self):
            return self.getToken(NmrStar2CSParser.Stop, 0)

        def cs_tags(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrStar2CSParser.Cs_tagsContext)
            else:
                return self.getTypedRuleContext(NmrStar2CSParser.Cs_tagsContext,i)


        def cs_data(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrStar2CSParser.Cs_dataContext)
            else:
                return self.getTypedRuleContext(NmrStar2CSParser.Cs_dataContext,i)


        def EOF(self):
            return self.getToken(NmrStar2CSParser.EOF, 0)

        def getRuleIndex(self):
            return NmrStar2CSParser.RULE_cs_loop

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCs_loop" ):
                listener.enterCs_loop(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCs_loop" ):
                listener.exitCs_loop(self)




    def cs_loop(self):

        localctx = NmrStar2CSParser.Cs_loopContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_cs_loop)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 55
            self.match(NmrStar2CSParser.Loop)
            self.state = 56
            self.match(NmrStar2CSParser.RETURN)
            self.state = 58 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 57
                self.cs_tags()
                self.state = 60 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & 4088) != 0)):
                    break

            self.state = 63 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 62
                self.cs_data()
                self.state = 65 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & 929792) != 0)):
                    break

            self.state = 67
            self.match(NmrStar2CSParser.Stop)
            self.state = 69
            self._errHandler.sync(self)
            la_ = self._interp.adaptivePredict(self._input,9,self._ctx)
            if la_ == 1:
                self.state = 68
                _la = self._input.LA(1)
                if not(_la==-1 or _la==21):
                    self._errHandler.recoverInline(self)
                else:
                    self._errHandler.reportMatch(self)
                    self.consume()


        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Cs_tagsContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def RETURN(self):
            return self.getToken(NmrStar2CSParser.RETURN, 0)

        def Atom_shift_assign_ID(self):
            return self.getToken(NmrStar2CSParser.Atom_shift_assign_ID, 0)

        def Residue_author_seq_code(self):
            return self.getToken(NmrStar2CSParser.Residue_author_seq_code, 0)

        def Residue_seq_code(self):
            return self.getToken(NmrStar2CSParser.Residue_seq_code, 0)

        def Residue_label(self):
            return self.getToken(NmrStar2CSParser.Residue_label, 0)

        def Atom_name(self):
            return self.getToken(NmrStar2CSParser.Atom_name, 0)

        def Atom_type(self):
            return self.getToken(NmrStar2CSParser.Atom_type, 0)

        def Chem_shift_value(self):
            return self.getToken(NmrStar2CSParser.Chem_shift_value, 0)

        def Chem_shift_value_error(self):
            return self.getToken(NmrStar2CSParser.Chem_shift_value_error, 0)

        def Chem_shift_ambiguity_code(self):
            return self.getToken(NmrStar2CSParser.Chem_shift_ambiguity_code, 0)

        def getRuleIndex(self):
            return NmrStar2CSParser.RULE_cs_tags

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCs_tags" ):
                listener.enterCs_tags(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCs_tags" ):
                listener.exitCs_tags(self)




    def cs_tags(self):

        localctx = NmrStar2CSParser.Cs_tagsContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_cs_tags)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 71
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & 4088) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
            self.state = 72
            self.match(NmrStar2CSParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Cs_dataContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def RETURN(self):
            return self.getToken(NmrStar2CSParser.RETURN, 0)

        def any_(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(NmrStar2CSParser.AnyContext)
            else:
                return self.getTypedRuleContext(NmrStar2CSParser.AnyContext,i)


        def getRuleIndex(self):
            return NmrStar2CSParser.RULE_cs_data

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterCs_data" ):
                listener.enterCs_data(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitCs_data" ):
                listener.exitCs_data(self)




    def cs_data(self):

        localctx = NmrStar2CSParser.Cs_dataContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_cs_data)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 75 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 74
                self.any_()
                self.state = 77 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not ((((_la) & ~0x3f) == 0 and ((1 << _la) & 929792) != 0)):
                    break

            self.state = 79
            self.match(NmrStar2CSParser.RETURN)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class AnyContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Float(self):
            return self.getToken(NmrStar2CSParser.Float, 0)

        def Integer(self):
            return self.getToken(NmrStar2CSParser.Integer, 0)

        def Simple_name(self):
            return self.getToken(NmrStar2CSParser.Simple_name, 0)

        def Double_quote_string(self):
            return self.getToken(NmrStar2CSParser.Double_quote_string, 0)

        def Single_quote_string(self):
            return self.getToken(NmrStar2CSParser.Single_quote_string, 0)

        def getRuleIndex(self):
            return NmrStar2CSParser.RULE_any

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterAny" ):
                listener.enterAny(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitAny" ):
                listener.exitAny(self)




    def any_(self):

        localctx = NmrStar2CSParser.AnyContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_any)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 81
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & 929792) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx








# Generated from BarePKParser.g4 by ANTLR 4.13.0
# encoding: utf-8
from antlr4 import *
from io import StringIO
import sys
if sys.version_info[1] > 5:
	from typing import TextIO
else:
	from typing.io import TextIO

def serializedATN():
    return [
        4,1,22,446,2,0,7,0,2,1,7,1,2,2,7,2,2,3,7,3,2,4,7,4,2,5,7,5,2,6,7,
        6,2,7,7,7,2,8,7,8,2,9,7,9,2,10,7,10,2,11,7,11,2,12,7,12,2,13,7,13,
        2,14,7,14,2,15,7,15,2,16,7,16,2,17,7,17,2,18,7,18,2,19,7,19,2,20,
        7,20,2,21,7,21,2,22,7,22,2,23,7,23,2,24,7,24,2,25,7,25,2,26,7,26,
        1,0,3,0,56,8,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,
        0,1,0,1,0,1,0,1,0,5,0,75,8,0,10,0,12,0,78,9,0,1,0,1,0,1,1,4,1,83,
        8,1,11,1,12,1,84,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,1,2,5,2,
        98,8,2,10,2,12,2,101,9,2,1,2,1,2,1,3,4,3,106,8,3,11,3,12,3,107,1,
        4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,1,4,5,
        4,126,8,4,10,4,12,4,129,9,4,1,4,1,4,1,5,4,5,134,8,5,11,5,12,5,135,
        1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,1,6,
        1,6,1,6,1,6,1,6,1,6,5,6,159,8,6,10,6,12,6,162,9,6,1,6,1,6,1,7,4,
        7,167,8,7,11,7,12,7,168,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,1,8,5,8,
        180,8,8,10,8,12,8,183,9,8,1,8,1,8,1,9,4,9,188,8,9,11,9,12,9,189,
        1,10,1,10,1,10,1,10,1,10,1,10,1,10,1,10,1,10,1,10,1,10,1,10,1,10,
        5,10,205,8,10,10,10,12,10,208,9,10,1,10,1,10,1,11,4,11,213,8,11,
        11,11,12,11,214,1,12,1,12,1,12,1,12,1,12,1,12,1,12,1,12,1,12,1,12,
        1,12,1,12,1,12,1,12,1,12,1,12,1,12,5,12,234,8,12,10,12,12,12,237,
        9,12,1,12,1,12,1,13,1,13,1,13,1,13,3,13,245,8,13,1,13,3,13,248,8,
        13,1,13,3,13,251,8,13,1,13,3,13,254,8,13,1,13,1,13,4,13,258,8,13,
        11,13,12,13,259,1,14,1,14,1,14,1,14,1,14,3,14,267,8,14,1,14,3,14,
        270,8,14,1,14,3,14,273,8,14,1,14,3,14,276,8,14,1,14,1,14,4,14,280,
        8,14,11,14,12,14,281,1,15,1,15,1,15,1,15,1,15,1,15,3,15,290,8,15,
        1,15,3,15,293,8,15,1,15,3,15,296,8,15,1,15,3,15,299,8,15,1,15,1,
        15,4,15,303,8,15,11,15,12,15,304,1,16,1,16,1,16,1,16,3,16,311,8,
        16,1,16,3,16,314,8,16,1,16,3,16,317,8,16,1,16,3,16,320,8,16,1,16,
        1,16,4,16,324,8,16,11,16,12,16,325,1,17,1,17,1,17,1,17,1,17,3,17,
        333,8,17,1,17,3,17,336,8,17,1,17,3,17,339,8,17,1,17,3,17,342,8,17,
        1,17,1,17,4,17,346,8,17,11,17,12,17,347,1,18,1,18,1,18,1,18,1,18,
        1,18,3,18,356,8,18,1,18,3,18,359,8,18,1,18,3,18,362,8,18,1,18,3,
        18,365,8,18,1,18,1,18,4,18,369,8,18,11,18,12,18,370,1,19,4,19,374,
        8,19,11,19,12,19,375,1,20,4,20,379,8,20,11,20,12,20,380,1,21,4,21,
        384,8,21,11,21,12,21,385,1,22,1,22,1,22,1,22,5,22,392,8,22,10,22,
        12,22,395,9,22,1,22,5,22,398,8,22,10,22,12,22,401,9,22,1,22,1,22,
        1,23,1,23,1,23,1,23,1,23,5,23,410,8,23,10,23,12,23,413,9,23,1,23,
        5,23,416,8,23,10,23,12,23,419,9,23,1,23,1,23,1,24,1,24,1,24,1,24,
        1,24,1,24,5,24,429,8,24,10,24,12,24,432,9,24,1,24,5,24,435,8,24,
        10,24,12,24,438,9,24,1,24,1,24,1,25,1,25,1,26,1,26,1,26,0,0,27,0,
        2,4,6,8,10,12,14,16,18,20,22,24,26,28,30,32,34,36,38,40,42,44,46,
        48,50,52,0,3,1,1,10,10,2,0,2,3,5,5,1,0,2,4,485,0,55,1,0,0,0,2,82,
        1,0,0,0,4,86,1,0,0,0,6,105,1,0,0,0,8,109,1,0,0,0,10,133,1,0,0,0,
        12,137,1,0,0,0,14,166,1,0,0,0,16,170,1,0,0,0,18,187,1,0,0,0,20,191,
        1,0,0,0,22,212,1,0,0,0,24,216,1,0,0,0,26,240,1,0,0,0,28,261,1,0,
        0,0,30,283,1,0,0,0,32,306,1,0,0,0,34,327,1,0,0,0,36,349,1,0,0,0,
        38,373,1,0,0,0,40,378,1,0,0,0,42,383,1,0,0,0,44,387,1,0,0,0,46,404,
        1,0,0,0,48,422,1,0,0,0,50,441,1,0,0,0,52,443,1,0,0,0,54,56,5,10,
        0,0,55,54,1,0,0,0,55,56,1,0,0,0,56,76,1,0,0,0,57,75,3,2,1,0,58,75,
        3,6,3,0,59,75,3,10,5,0,60,75,3,14,7,0,61,75,3,18,9,0,62,75,3,22,
        11,0,63,75,3,26,13,0,64,75,3,28,14,0,65,75,3,30,15,0,66,75,3,32,
        16,0,67,75,3,34,17,0,68,75,3,36,18,0,69,75,3,38,19,0,70,75,3,40,
        20,0,71,72,3,42,21,0,72,73,5,10,0,0,73,75,1,0,0,0,74,57,1,0,0,0,
        74,58,1,0,0,0,74,59,1,0,0,0,74,60,1,0,0,0,74,61,1,0,0,0,74,62,1,
        0,0,0,74,63,1,0,0,0,74,64,1,0,0,0,74,65,1,0,0,0,74,66,1,0,0,0,74,
        67,1,0,0,0,74,68,1,0,0,0,74,69,1,0,0,0,74,70,1,0,0,0,74,71,1,0,0,
        0,75,78,1,0,0,0,76,74,1,0,0,0,76,77,1,0,0,0,77,79,1,0,0,0,78,76,
        1,0,0,0,79,80,5,0,0,1,80,1,1,0,0,0,81,83,3,4,2,0,82,81,1,0,0,0,83,
        84,1,0,0,0,84,82,1,0,0,0,84,85,1,0,0,0,85,3,1,0,0,0,86,87,5,8,0,
        0,87,88,5,2,0,0,88,89,5,8,0,0,89,90,5,8,0,0,90,91,3,50,25,0,91,92,
        5,8,0,0,92,93,5,2,0,0,93,94,5,8,0,0,94,95,5,8,0,0,95,99,3,50,25,
        0,96,98,3,52,26,0,97,96,1,0,0,0,98,101,1,0,0,0,99,97,1,0,0,0,99,
        100,1,0,0,0,100,102,1,0,0,0,101,99,1,0,0,0,102,103,7,0,0,0,103,5,
        1,0,0,0,104,106,3,8,4,0,105,104,1,0,0,0,106,107,1,0,0,0,107,105,
        1,0,0,0,107,108,1,0,0,0,108,7,1,0,0,0,109,110,5,8,0,0,110,111,5,
        2,0,0,111,112,5,8,0,0,112,113,5,8,0,0,113,114,3,50,25,0,114,115,
        5,8,0,0,115,116,5,2,0,0,116,117,5,8,0,0,117,118,5,8,0,0,118,119,
        3,50,25,0,119,120,5,8,0,0,120,121,5,2,0,0,121,122,5,8,0,0,122,123,
        5,8,0,0,123,127,3,50,25,0,124,126,3,52,26,0,125,124,1,0,0,0,126,
        129,1,0,0,0,127,125,1,0,0,0,127,128,1,0,0,0,128,130,1,0,0,0,129,
        127,1,0,0,0,130,131,7,0,0,0,131,9,1,0,0,0,132,134,3,12,6,0,133,132,
        1,0,0,0,134,135,1,0,0,0,135,133,1,0,0,0,135,136,1,0,0,0,136,11,1,
        0,0,0,137,138,5,8,0,0,138,139,5,2,0,0,139,140,5,8,0,0,140,141,5,
        8,0,0,141,142,3,50,25,0,142,143,5,8,0,0,143,144,5,2,0,0,144,145,
        5,8,0,0,145,146,5,8,0,0,146,147,3,50,25,0,147,148,5,8,0,0,148,149,
        5,2,0,0,149,150,5,8,0,0,150,151,5,8,0,0,151,152,3,50,25,0,152,153,
        5,8,0,0,153,154,5,2,0,0,154,155,5,8,0,0,155,156,5,8,0,0,156,160,
        3,50,25,0,157,159,3,52,26,0,158,157,1,0,0,0,159,162,1,0,0,0,160,
        158,1,0,0,0,160,161,1,0,0,0,161,163,1,0,0,0,162,160,1,0,0,0,163,
        164,7,0,0,0,164,13,1,0,0,0,165,167,3,16,8,0,166,165,1,0,0,0,167,
        168,1,0,0,0,168,166,1,0,0,0,168,169,1,0,0,0,169,15,1,0,0,0,170,171,
        5,2,0,0,171,172,5,8,0,0,172,173,5,8,0,0,173,174,3,50,25,0,174,175,
        5,2,0,0,175,176,5,8,0,0,176,177,5,8,0,0,177,181,3,50,25,0,178,180,
        3,52,26,0,179,178,1,0,0,0,180,183,1,0,0,0,181,179,1,0,0,0,181,182,
        1,0,0,0,182,184,1,0,0,0,183,181,1,0,0,0,184,185,7,0,0,0,185,17,1,
        0,0,0,186,188,3,20,10,0,187,186,1,0,0,0,188,189,1,0,0,0,189,187,
        1,0,0,0,189,190,1,0,0,0,190,19,1,0,0,0,191,192,5,2,0,0,192,193,5,
        8,0,0,193,194,5,8,0,0,194,195,3,50,25,0,195,196,5,2,0,0,196,197,
        5,8,0,0,197,198,5,8,0,0,198,199,3,50,25,0,199,200,5,2,0,0,200,201,
        5,8,0,0,201,202,5,8,0,0,202,206,3,50,25,0,203,205,3,52,26,0,204,
        203,1,0,0,0,205,208,1,0,0,0,206,204,1,0,0,0,206,207,1,0,0,0,207,
        209,1,0,0,0,208,206,1,0,0,0,209,210,7,0,0,0,210,21,1,0,0,0,211,213,
        3,24,12,0,212,211,1,0,0,0,213,214,1,0,0,0,214,212,1,0,0,0,214,215,
        1,0,0,0,215,23,1,0,0,0,216,217,5,2,0,0,217,218,5,8,0,0,218,219,5,
        8,0,0,219,220,3,50,25,0,220,221,5,2,0,0,221,222,5,8,0,0,222,223,
        5,8,0,0,223,224,3,50,25,0,224,225,5,2,0,0,225,226,5,8,0,0,226,227,
        5,8,0,0,227,228,3,50,25,0,228,229,5,2,0,0,229,230,5,8,0,0,230,231,
        5,8,0,0,231,235,3,50,25,0,232,234,3,52,26,0,233,232,1,0,0,0,234,
        237,1,0,0,0,235,233,1,0,0,0,235,236,1,0,0,0,236,238,1,0,0,0,237,
        235,1,0,0,0,238,239,7,0,0,0,239,25,1,0,0,0,240,241,5,1,0,0,241,242,
        5,13,0,0,242,244,5,14,0,0,243,245,5,17,0,0,244,243,1,0,0,0,244,245,
        1,0,0,0,245,247,1,0,0,0,246,248,5,18,0,0,247,246,1,0,0,0,247,248,
        1,0,0,0,248,250,1,0,0,0,249,251,5,19,0,0,250,249,1,0,0,0,250,251,
        1,0,0,0,251,253,1,0,0,0,252,254,5,20,0,0,253,252,1,0,0,0,253,254,
        1,0,0,0,254,255,1,0,0,0,255,257,5,22,0,0,256,258,3,44,22,0,257,256,
        1,0,0,0,258,259,1,0,0,0,259,257,1,0,0,0,259,260,1,0,0,0,260,27,1,
        0,0,0,261,262,5,1,0,0,262,263,5,13,0,0,263,264,5,14,0,0,264,266,
        5,15,0,0,265,267,5,17,0,0,266,265,1,0,0,0,266,267,1,0,0,0,267,269,
        1,0,0,0,268,270,5,18,0,0,269,268,1,0,0,0,269,270,1,0,0,0,270,272,
        1,0,0,0,271,273,5,19,0,0,272,271,1,0,0,0,272,273,1,0,0,0,273,275,
        1,0,0,0,274,276,5,20,0,0,275,274,1,0,0,0,275,276,1,0,0,0,276,277,
        1,0,0,0,277,279,5,22,0,0,278,280,3,46,23,0,279,278,1,0,0,0,280,281,
        1,0,0,0,281,279,1,0,0,0,281,282,1,0,0,0,282,29,1,0,0,0,283,284,5,
        1,0,0,284,285,5,13,0,0,285,286,5,14,0,0,286,287,5,15,0,0,287,289,
        5,16,0,0,288,290,5,17,0,0,289,288,1,0,0,0,289,290,1,0,0,0,290,292,
        1,0,0,0,291,293,5,18,0,0,292,291,1,0,0,0,292,293,1,0,0,0,293,295,
        1,0,0,0,294,296,5,19,0,0,295,294,1,0,0,0,295,296,1,0,0,0,296,298,
        1,0,0,0,297,299,5,20,0,0,298,297,1,0,0,0,298,299,1,0,0,0,299,300,
        1,0,0,0,300,302,5,22,0,0,301,303,3,48,24,0,302,301,1,0,0,0,303,304,
        1,0,0,0,304,302,1,0,0,0,304,305,1,0,0,0,305,31,1,0,0,0,306,307,5,
        1,0,0,307,308,5,14,0,0,308,310,5,13,0,0,309,311,5,17,0,0,310,309,
        1,0,0,0,310,311,1,0,0,0,311,313,1,0,0,0,312,314,5,18,0,0,313,312,
        1,0,0,0,313,314,1,0,0,0,314,316,1,0,0,0,315,317,5,19,0,0,316,315,
        1,0,0,0,316,317,1,0,0,0,317,319,1,0,0,0,318,320,5,20,0,0,319,318,
        1,0,0,0,319,320,1,0,0,0,320,321,1,0,0,0,321,323,5,22,0,0,322,324,
        3,44,22,0,323,322,1,0,0,0,324,325,1,0,0,0,325,323,1,0,0,0,325,326,
        1,0,0,0,326,33,1,0,0,0,327,328,5,1,0,0,328,329,5,15,0,0,329,330,
        5,14,0,0,330,332,5,13,0,0,331,333,5,17,0,0,332,331,1,0,0,0,332,333,
        1,0,0,0,333,335,1,0,0,0,334,336,5,18,0,0,335,334,1,0,0,0,335,336,
        1,0,0,0,336,338,1,0,0,0,337,339,5,19,0,0,338,337,1,0,0,0,338,339,
        1,0,0,0,339,341,1,0,0,0,340,342,5,20,0,0,341,340,1,0,0,0,341,342,
        1,0,0,0,342,343,1,0,0,0,343,345,5,22,0,0,344,346,3,46,23,0,345,344,
        1,0,0,0,346,347,1,0,0,0,347,345,1,0,0,0,347,348,1,0,0,0,348,35,1,
        0,0,0,349,350,5,1,0,0,350,351,5,16,0,0,351,352,5,15,0,0,352,353,
        5,14,0,0,353,355,5,13,0,0,354,356,5,17,0,0,355,354,1,0,0,0,355,356,
        1,0,0,0,356,358,1,0,0,0,357,359,5,18,0,0,358,357,1,0,0,0,358,359,
        1,0,0,0,359,361,1,0,0,0,360,362,5,19,0,0,361,360,1,0,0,0,361,362,
        1,0,0,0,362,364,1,0,0,0,363,365,5,20,0,0,364,363,1,0,0,0,364,365,
        1,0,0,0,365,366,1,0,0,0,366,368,5,22,0,0,367,369,3,48,24,0,368,367,
        1,0,0,0,369,370,1,0,0,0,370,368,1,0,0,0,370,371,1,0,0,0,371,37,1,
        0,0,0,372,374,3,44,22,0,373,372,1,0,0,0,374,375,1,0,0,0,375,373,
        1,0,0,0,375,376,1,0,0,0,376,39,1,0,0,0,377,379,3,46,23,0,378,377,
        1,0,0,0,379,380,1,0,0,0,380,378,1,0,0,0,380,381,1,0,0,0,381,41,1,
        0,0,0,382,384,3,48,24,0,383,382,1,0,0,0,384,385,1,0,0,0,385,383,
        1,0,0,0,385,386,1,0,0,0,386,43,1,0,0,0,387,388,5,2,0,0,388,389,3,
        50,25,0,389,393,3,50,25,0,390,392,3,52,26,0,391,390,1,0,0,0,392,
        395,1,0,0,0,393,391,1,0,0,0,393,394,1,0,0,0,394,399,1,0,0,0,395,
        393,1,0,0,0,396,398,5,8,0,0,397,396,1,0,0,0,398,401,1,0,0,0,399,
        397,1,0,0,0,399,400,1,0,0,0,400,402,1,0,0,0,401,399,1,0,0,0,402,
        403,7,0,0,0,403,45,1,0,0,0,404,405,5,2,0,0,405,406,3,50,25,0,406,
        407,3,50,25,0,407,411,3,50,25,0,408,410,3,52,26,0,409,408,1,0,0,
        0,410,413,1,0,0,0,411,409,1,0,0,0,411,412,1,0,0,0,412,417,1,0,0,
        0,413,411,1,0,0,0,414,416,5,8,0,0,415,414,1,0,0,0,416,419,1,0,0,
        0,417,415,1,0,0,0,417,418,1,0,0,0,418,420,1,0,0,0,419,417,1,0,0,
        0,420,421,7,0,0,0,421,47,1,0,0,0,422,423,5,2,0,0,423,424,3,50,25,
        0,424,425,3,50,25,0,425,426,3,50,25,0,426,430,3,50,25,0,427,429,
        3,52,26,0,428,427,1,0,0,0,429,432,1,0,0,0,430,428,1,0,0,0,430,431,
        1,0,0,0,431,436,1,0,0,0,432,430,1,0,0,0,433,435,5,8,0,0,434,433,
        1,0,0,0,435,438,1,0,0,0,436,434,1,0,0,0,436,437,1,0,0,0,437,439,
        1,0,0,0,438,436,1,0,0,0,439,440,7,0,0,0,440,49,1,0,0,0,441,442,7,
        1,0,0,442,51,1,0,0,0,443,444,7,2,0,0,444,53,1,0,0,0,54,55,74,76,
        84,99,107,127,135,160,168,181,189,206,214,235,244,247,250,253,259,
        266,269,272,275,281,289,292,295,298,304,310,313,316,319,325,332,
        335,338,341,347,355,358,361,364,370,375,380,385,393,399,411,417,
        430,436
    ]

class BarePKParser ( Parser ):

    grammarFileName = "BarePKParser.g4"

    atn = ATNDeserializer().deserialize(serializedATN())

    decisionsToDFA = [ DFA(ds, i) for i, ds in enumerate(atn.decisionToState) ]

    sharedContextCache = PredictionContextCache()

    literalNames = [ "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "<INVALID>", "<INVALID>", 
                     "<INVALID>", "<INVALID>", "'Volume'" ]

    symbolicNames = [ "<INVALID>", "Peak", "Integer", "Float", "Real", "Ambig_float", 
                      "SHARP_COMMENT", "EXCLM_COMMENT", "Simple_name", "SPACE", 
                      "RETURN", "SECTION_COMMENT", "LINE_COMMENT", "X_ppm", 
                      "Y_ppm", "Z_ppm", "A_ppm", "Amplitude", "Volume", 
                      "Label", "Comment", "SPACE_FO", "RETURN_FO" ]

    RULE_bare_pk = 0
    RULE_peak_list_2d = 1
    RULE_peak_2d = 2
    RULE_peak_list_3d = 3
    RULE_peak_3d = 4
    RULE_peak_list_4d = 5
    RULE_peak_4d = 6
    RULE_peak_list_wo_chain_2d = 7
    RULE_peak_wo_chain_2d = 8
    RULE_peak_list_wo_chain_3d = 9
    RULE_peak_wo_chain_3d = 10
    RULE_peak_list_wo_chain_4d = 11
    RULE_peak_wo_chain_4d = 12
    RULE_raw_format_2d = 13
    RULE_raw_format_3d = 14
    RULE_raw_format_4d = 15
    RULE_rev_raw_format_2d = 16
    RULE_rev_raw_format_3d = 17
    RULE_rev_raw_format_4d = 18
    RULE_raw_format_wo_label_2d = 19
    RULE_raw_format_wo_label_3d = 20
    RULE_raw_format_wo_label_4d = 21
    RULE_peak_list_raw_2d = 22
    RULE_peak_list_raw_3d = 23
    RULE_peak_list_raw_4d = 24
    RULE_position = 25
    RULE_number = 26

    ruleNames =  [ "bare_pk", "peak_list_2d", "peak_2d", "peak_list_3d", 
                   "peak_3d", "peak_list_4d", "peak_4d", "peak_list_wo_chain_2d", 
                   "peak_wo_chain_2d", "peak_list_wo_chain_3d", "peak_wo_chain_3d", 
                   "peak_list_wo_chain_4d", "peak_wo_chain_4d", "raw_format_2d", 
                   "raw_format_3d", "raw_format_4d", "rev_raw_format_2d", 
                   "rev_raw_format_3d", "rev_raw_format_4d", "raw_format_wo_label_2d", 
                   "raw_format_wo_label_3d", "raw_format_wo_label_4d", "peak_list_raw_2d", 
                   "peak_list_raw_3d", "peak_list_raw_4d", "position", "number" ]

    EOF = Token.EOF
    Peak=1
    Integer=2
    Float=3
    Real=4
    Ambig_float=5
    SHARP_COMMENT=6
    EXCLM_COMMENT=7
    Simple_name=8
    SPACE=9
    RETURN=10
    SECTION_COMMENT=11
    LINE_COMMENT=12
    X_ppm=13
    Y_ppm=14
    Z_ppm=15
    A_ppm=16
    Amplitude=17
    Volume=18
    Label=19
    Comment=20
    SPACE_FO=21
    RETURN_FO=22

    def __init__(self, input:TokenStream, output:TextIO = sys.stdout):
        super().__init__(input, output)
        self.checkVersion("4.13.0")
        self._interp = ParserATNSimulator(self, self.atn, self.decisionsToDFA, self.sharedContextCache)
        self._predicates = None




    class Bare_pkContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def RETURN(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.RETURN)
            else:
                return self.getToken(BarePKParser.RETURN, i)

        def peak_list_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_2dContext,i)


        def peak_list_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_3dContext,i)


        def peak_list_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_4dContext,i)


        def peak_list_wo_chain_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_wo_chain_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_wo_chain_2dContext,i)


        def peak_list_wo_chain_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_wo_chain_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_wo_chain_3dContext,i)


        def peak_list_wo_chain_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_wo_chain_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_wo_chain_4dContext,i)


        def raw_format_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Raw_format_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Raw_format_2dContext,i)


        def raw_format_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Raw_format_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Raw_format_3dContext,i)


        def raw_format_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Raw_format_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Raw_format_4dContext,i)


        def rev_raw_format_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Rev_raw_format_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Rev_raw_format_2dContext,i)


        def rev_raw_format_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Rev_raw_format_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Rev_raw_format_3dContext,i)


        def rev_raw_format_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Rev_raw_format_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Rev_raw_format_4dContext,i)


        def raw_format_wo_label_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Raw_format_wo_label_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Raw_format_wo_label_2dContext,i)


        def raw_format_wo_label_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Raw_format_wo_label_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Raw_format_wo_label_3dContext,i)


        def raw_format_wo_label_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Raw_format_wo_label_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Raw_format_wo_label_4dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_bare_pk

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterBare_pk" ):
                listener.enterBare_pk(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitBare_pk" ):
                listener.exitBare_pk(self)




    def bare_pk(self):

        localctx = BarePKParser.Bare_pkContext(self, self._ctx, self.state)
        self.enterRule(localctx, 0, self.RULE_bare_pk)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 55
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==10:
                self.state = 54
                self.match(BarePKParser.RETURN)


            self.state = 76
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 262) != 0):
                self.state = 74
                self._errHandler.sync(self)
                la_ = self._interp.adaptivePredict(self._input,1,self._ctx)
                if la_ == 1:
                    self.state = 57
                    self.peak_list_2d()
                    pass

                elif la_ == 2:
                    self.state = 58
                    self.peak_list_3d()
                    pass

                elif la_ == 3:
                    self.state = 59
                    self.peak_list_4d()
                    pass

                elif la_ == 4:
                    self.state = 60
                    self.peak_list_wo_chain_2d()
                    pass

                elif la_ == 5:
                    self.state = 61
                    self.peak_list_wo_chain_3d()
                    pass

                elif la_ == 6:
                    self.state = 62
                    self.peak_list_wo_chain_4d()
                    pass

                elif la_ == 7:
                    self.state = 63
                    self.raw_format_2d()
                    pass

                elif la_ == 8:
                    self.state = 64
                    self.raw_format_3d()
                    pass

                elif la_ == 9:
                    self.state = 65
                    self.raw_format_4d()
                    pass

                elif la_ == 10:
                    self.state = 66
                    self.rev_raw_format_2d()
                    pass

                elif la_ == 11:
                    self.state = 67
                    self.rev_raw_format_3d()
                    pass

                elif la_ == 12:
                    self.state = 68
                    self.rev_raw_format_4d()
                    pass

                elif la_ == 13:
                    self.state = 69
                    self.raw_format_wo_label_2d()
                    pass

                elif la_ == 14:
                    self.state = 70
                    self.raw_format_wo_label_3d()
                    pass

                elif la_ == 15:
                    self.state = 71
                    self.raw_format_wo_label_4d()
                    self.state = 72
                    self.match(BarePKParser.RETURN)
                    pass


                self.state = 78
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 79
            self.match(BarePKParser.EOF)
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_2dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_2d" ):
                listener.enterPeak_list_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_2d" ):
                listener.exitPeak_list_2d(self)




    def peak_list_2d(self):

        localctx = BarePKParser.Peak_list_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 2, self.RULE_peak_list_2d)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 82 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 81
                    self.peak_2d()

                else:
                    raise NoViableAltException(self)
                self.state = 84 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,3,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Integer)
            else:
                return self.getToken(BarePKParser.Integer, i)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_2d" ):
                listener.enterPeak_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_2d" ):
                listener.exitPeak_2d(self)




    def peak_2d(self):

        localctx = BarePKParser.Peak_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 4, self.RULE_peak_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 86
            self.match(BarePKParser.Simple_name)
            self.state = 87
            self.match(BarePKParser.Integer)
            self.state = 88
            self.match(BarePKParser.Simple_name)
            self.state = 89
            self.match(BarePKParser.Simple_name)
            self.state = 90
            self.position()
            self.state = 91
            self.match(BarePKParser.Simple_name)
            self.state = 92
            self.match(BarePKParser.Integer)
            self.state = 93
            self.match(BarePKParser.Simple_name)
            self.state = 94
            self.match(BarePKParser.Simple_name)
            self.state = 95
            self.position()
            self.state = 99
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 96
                self.number()
                self.state = 101
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 102
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_3dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_3d" ):
                listener.enterPeak_list_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_3d" ):
                listener.exitPeak_list_3d(self)




    def peak_list_3d(self):

        localctx = BarePKParser.Peak_list_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 6, self.RULE_peak_list_3d)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 105 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 104
                    self.peak_3d()

                else:
                    raise NoViableAltException(self)
                self.state = 107 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,5,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Integer)
            else:
                return self.getToken(BarePKParser.Integer, i)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_3d" ):
                listener.enterPeak_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_3d" ):
                listener.exitPeak_3d(self)




    def peak_3d(self):

        localctx = BarePKParser.Peak_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 8, self.RULE_peak_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 109
            self.match(BarePKParser.Simple_name)
            self.state = 110
            self.match(BarePKParser.Integer)
            self.state = 111
            self.match(BarePKParser.Simple_name)
            self.state = 112
            self.match(BarePKParser.Simple_name)
            self.state = 113
            self.position()
            self.state = 114
            self.match(BarePKParser.Simple_name)
            self.state = 115
            self.match(BarePKParser.Integer)
            self.state = 116
            self.match(BarePKParser.Simple_name)
            self.state = 117
            self.match(BarePKParser.Simple_name)
            self.state = 118
            self.position()
            self.state = 119
            self.match(BarePKParser.Simple_name)
            self.state = 120
            self.match(BarePKParser.Integer)
            self.state = 121
            self.match(BarePKParser.Simple_name)
            self.state = 122
            self.match(BarePKParser.Simple_name)
            self.state = 123
            self.position()
            self.state = 127
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 124
                self.number()
                self.state = 129
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 130
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_4dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_4d" ):
                listener.enterPeak_list_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_4d" ):
                listener.exitPeak_list_4d(self)




    def peak_list_4d(self):

        localctx = BarePKParser.Peak_list_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 10, self.RULE_peak_list_4d)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 133 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 132
                    self.peak_4d()

                else:
                    raise NoViableAltException(self)
                self.state = 135 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,7,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Integer)
            else:
                return self.getToken(BarePKParser.Integer, i)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_4d" ):
                listener.enterPeak_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_4d" ):
                listener.exitPeak_4d(self)




    def peak_4d(self):

        localctx = BarePKParser.Peak_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 12, self.RULE_peak_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 137
            self.match(BarePKParser.Simple_name)
            self.state = 138
            self.match(BarePKParser.Integer)
            self.state = 139
            self.match(BarePKParser.Simple_name)
            self.state = 140
            self.match(BarePKParser.Simple_name)
            self.state = 141
            self.position()
            self.state = 142
            self.match(BarePKParser.Simple_name)
            self.state = 143
            self.match(BarePKParser.Integer)
            self.state = 144
            self.match(BarePKParser.Simple_name)
            self.state = 145
            self.match(BarePKParser.Simple_name)
            self.state = 146
            self.position()
            self.state = 147
            self.match(BarePKParser.Simple_name)
            self.state = 148
            self.match(BarePKParser.Integer)
            self.state = 149
            self.match(BarePKParser.Simple_name)
            self.state = 150
            self.match(BarePKParser.Simple_name)
            self.state = 151
            self.position()
            self.state = 152
            self.match(BarePKParser.Simple_name)
            self.state = 153
            self.match(BarePKParser.Integer)
            self.state = 154
            self.match(BarePKParser.Simple_name)
            self.state = 155
            self.match(BarePKParser.Simple_name)
            self.state = 156
            self.position()
            self.state = 160
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 157
                self.number()
                self.state = 162
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 163
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_wo_chain_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_wo_chain_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_wo_chain_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_wo_chain_2dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_wo_chain_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_wo_chain_2d" ):
                listener.enterPeak_list_wo_chain_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_wo_chain_2d" ):
                listener.exitPeak_list_wo_chain_2d(self)




    def peak_list_wo_chain_2d(self):

        localctx = BarePKParser.Peak_list_wo_chain_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 14, self.RULE_peak_list_wo_chain_2d)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 166 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 165
                    self.peak_wo_chain_2d()

                else:
                    raise NoViableAltException(self)
                self.state = 168 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,9,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_wo_chain_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Integer)
            else:
                return self.getToken(BarePKParser.Integer, i)

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_wo_chain_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_wo_chain_2d" ):
                listener.enterPeak_wo_chain_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_wo_chain_2d" ):
                listener.exitPeak_wo_chain_2d(self)




    def peak_wo_chain_2d(self):

        localctx = BarePKParser.Peak_wo_chain_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 16, self.RULE_peak_wo_chain_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 170
            self.match(BarePKParser.Integer)
            self.state = 171
            self.match(BarePKParser.Simple_name)
            self.state = 172
            self.match(BarePKParser.Simple_name)
            self.state = 173
            self.position()
            self.state = 174
            self.match(BarePKParser.Integer)
            self.state = 175
            self.match(BarePKParser.Simple_name)
            self.state = 176
            self.match(BarePKParser.Simple_name)
            self.state = 177
            self.position()
            self.state = 181
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 178
                self.number()
                self.state = 183
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 184
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_wo_chain_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_wo_chain_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_wo_chain_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_wo_chain_3dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_wo_chain_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_wo_chain_3d" ):
                listener.enterPeak_list_wo_chain_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_wo_chain_3d" ):
                listener.exitPeak_list_wo_chain_3d(self)




    def peak_list_wo_chain_3d(self):

        localctx = BarePKParser.Peak_list_wo_chain_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 18, self.RULE_peak_list_wo_chain_3d)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 187 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 186
                    self.peak_wo_chain_3d()

                else:
                    raise NoViableAltException(self)
                self.state = 189 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,11,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_wo_chain_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Integer)
            else:
                return self.getToken(BarePKParser.Integer, i)

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_wo_chain_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_wo_chain_3d" ):
                listener.enterPeak_wo_chain_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_wo_chain_3d" ):
                listener.exitPeak_wo_chain_3d(self)




    def peak_wo_chain_3d(self):

        localctx = BarePKParser.Peak_wo_chain_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 20, self.RULE_peak_wo_chain_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 191
            self.match(BarePKParser.Integer)
            self.state = 192
            self.match(BarePKParser.Simple_name)
            self.state = 193
            self.match(BarePKParser.Simple_name)
            self.state = 194
            self.position()
            self.state = 195
            self.match(BarePKParser.Integer)
            self.state = 196
            self.match(BarePKParser.Simple_name)
            self.state = 197
            self.match(BarePKParser.Simple_name)
            self.state = 198
            self.position()
            self.state = 199
            self.match(BarePKParser.Integer)
            self.state = 200
            self.match(BarePKParser.Simple_name)
            self.state = 201
            self.match(BarePKParser.Simple_name)
            self.state = 202
            self.position()
            self.state = 206
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 203
                self.number()
                self.state = 208
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 209
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_wo_chain_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_wo_chain_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_wo_chain_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_wo_chain_4dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_wo_chain_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_wo_chain_4d" ):
                listener.enterPeak_list_wo_chain_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_wo_chain_4d" ):
                listener.exitPeak_list_wo_chain_4d(self)




    def peak_list_wo_chain_4d(self):

        localctx = BarePKParser.Peak_list_wo_chain_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 22, self.RULE_peak_list_wo_chain_4d)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 212 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 211
                    self.peak_wo_chain_4d()

                else:
                    raise NoViableAltException(self)
                self.state = 214 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,13,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_wo_chain_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Integer)
            else:
                return self.getToken(BarePKParser.Integer, i)

        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_peak_wo_chain_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_wo_chain_4d" ):
                listener.enterPeak_wo_chain_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_wo_chain_4d" ):
                listener.exitPeak_wo_chain_4d(self)




    def peak_wo_chain_4d(self):

        localctx = BarePKParser.Peak_wo_chain_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 24, self.RULE_peak_wo_chain_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 216
            self.match(BarePKParser.Integer)
            self.state = 217
            self.match(BarePKParser.Simple_name)
            self.state = 218
            self.match(BarePKParser.Simple_name)
            self.state = 219
            self.position()
            self.state = 220
            self.match(BarePKParser.Integer)
            self.state = 221
            self.match(BarePKParser.Simple_name)
            self.state = 222
            self.match(BarePKParser.Simple_name)
            self.state = 223
            self.position()
            self.state = 224
            self.match(BarePKParser.Integer)
            self.state = 225
            self.match(BarePKParser.Simple_name)
            self.state = 226
            self.match(BarePKParser.Simple_name)
            self.state = 227
            self.position()
            self.state = 228
            self.match(BarePKParser.Integer)
            self.state = 229
            self.match(BarePKParser.Simple_name)
            self.state = 230
            self.match(BarePKParser.Simple_name)
            self.state = 231
            self.position()
            self.state = 235
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 232
                self.number()
                self.state = 237
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 238
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Raw_format_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Peak(self):
            return self.getToken(BarePKParser.Peak, 0)

        def X_ppm(self):
            return self.getToken(BarePKParser.X_ppm, 0)

        def Y_ppm(self):
            return self.getToken(BarePKParser.Y_ppm, 0)

        def RETURN_FO(self):
            return self.getToken(BarePKParser.RETURN_FO, 0)

        def Amplitude(self):
            return self.getToken(BarePKParser.Amplitude, 0)

        def Volume(self):
            return self.getToken(BarePKParser.Volume, 0)

        def Label(self):
            return self.getToken(BarePKParser.Label, 0)

        def Comment(self):
            return self.getToken(BarePKParser.Comment, 0)

        def peak_list_raw_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_2dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_raw_format_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRaw_format_2d" ):
                listener.enterRaw_format_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRaw_format_2d" ):
                listener.exitRaw_format_2d(self)




    def raw_format_2d(self):

        localctx = BarePKParser.Raw_format_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 26, self.RULE_raw_format_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 240
            self.match(BarePKParser.Peak)
            self.state = 241
            self.match(BarePKParser.X_ppm)
            self.state = 242
            self.match(BarePKParser.Y_ppm)
            self.state = 244
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==17:
                self.state = 243
                self.match(BarePKParser.Amplitude)


            self.state = 247
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==18:
                self.state = 246
                self.match(BarePKParser.Volume)


            self.state = 250
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==19:
                self.state = 249
                self.match(BarePKParser.Label)


            self.state = 253
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==20:
                self.state = 252
                self.match(BarePKParser.Comment)


            self.state = 255
            self.match(BarePKParser.RETURN_FO)
            self.state = 257 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 256
                    self.peak_list_raw_2d()

                else:
                    raise NoViableAltException(self)
                self.state = 259 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,19,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Raw_format_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Peak(self):
            return self.getToken(BarePKParser.Peak, 0)

        def X_ppm(self):
            return self.getToken(BarePKParser.X_ppm, 0)

        def Y_ppm(self):
            return self.getToken(BarePKParser.Y_ppm, 0)

        def Z_ppm(self):
            return self.getToken(BarePKParser.Z_ppm, 0)

        def RETURN_FO(self):
            return self.getToken(BarePKParser.RETURN_FO, 0)

        def Amplitude(self):
            return self.getToken(BarePKParser.Amplitude, 0)

        def Volume(self):
            return self.getToken(BarePKParser.Volume, 0)

        def Label(self):
            return self.getToken(BarePKParser.Label, 0)

        def Comment(self):
            return self.getToken(BarePKParser.Comment, 0)

        def peak_list_raw_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_3dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_raw_format_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRaw_format_3d" ):
                listener.enterRaw_format_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRaw_format_3d" ):
                listener.exitRaw_format_3d(self)




    def raw_format_3d(self):

        localctx = BarePKParser.Raw_format_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 28, self.RULE_raw_format_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 261
            self.match(BarePKParser.Peak)
            self.state = 262
            self.match(BarePKParser.X_ppm)
            self.state = 263
            self.match(BarePKParser.Y_ppm)
            self.state = 264
            self.match(BarePKParser.Z_ppm)
            self.state = 266
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==17:
                self.state = 265
                self.match(BarePKParser.Amplitude)


            self.state = 269
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==18:
                self.state = 268
                self.match(BarePKParser.Volume)


            self.state = 272
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==19:
                self.state = 271
                self.match(BarePKParser.Label)


            self.state = 275
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==20:
                self.state = 274
                self.match(BarePKParser.Comment)


            self.state = 277
            self.match(BarePKParser.RETURN_FO)
            self.state = 279 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 278
                    self.peak_list_raw_3d()

                else:
                    raise NoViableAltException(self)
                self.state = 281 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,24,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Raw_format_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Peak(self):
            return self.getToken(BarePKParser.Peak, 0)

        def X_ppm(self):
            return self.getToken(BarePKParser.X_ppm, 0)

        def Y_ppm(self):
            return self.getToken(BarePKParser.Y_ppm, 0)

        def Z_ppm(self):
            return self.getToken(BarePKParser.Z_ppm, 0)

        def A_ppm(self):
            return self.getToken(BarePKParser.A_ppm, 0)

        def RETURN_FO(self):
            return self.getToken(BarePKParser.RETURN_FO, 0)

        def Amplitude(self):
            return self.getToken(BarePKParser.Amplitude, 0)

        def Volume(self):
            return self.getToken(BarePKParser.Volume, 0)

        def Label(self):
            return self.getToken(BarePKParser.Label, 0)

        def Comment(self):
            return self.getToken(BarePKParser.Comment, 0)

        def peak_list_raw_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_4dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_raw_format_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRaw_format_4d" ):
                listener.enterRaw_format_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRaw_format_4d" ):
                listener.exitRaw_format_4d(self)




    def raw_format_4d(self):

        localctx = BarePKParser.Raw_format_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 30, self.RULE_raw_format_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 283
            self.match(BarePKParser.Peak)
            self.state = 284
            self.match(BarePKParser.X_ppm)
            self.state = 285
            self.match(BarePKParser.Y_ppm)
            self.state = 286
            self.match(BarePKParser.Z_ppm)
            self.state = 287
            self.match(BarePKParser.A_ppm)
            self.state = 289
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==17:
                self.state = 288
                self.match(BarePKParser.Amplitude)


            self.state = 292
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==18:
                self.state = 291
                self.match(BarePKParser.Volume)


            self.state = 295
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==19:
                self.state = 294
                self.match(BarePKParser.Label)


            self.state = 298
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==20:
                self.state = 297
                self.match(BarePKParser.Comment)


            self.state = 300
            self.match(BarePKParser.RETURN_FO)
            self.state = 302 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 301
                    self.peak_list_raw_4d()

                else:
                    raise NoViableAltException(self)
                self.state = 304 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,29,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Rev_raw_format_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Peak(self):
            return self.getToken(BarePKParser.Peak, 0)

        def Y_ppm(self):
            return self.getToken(BarePKParser.Y_ppm, 0)

        def X_ppm(self):
            return self.getToken(BarePKParser.X_ppm, 0)

        def RETURN_FO(self):
            return self.getToken(BarePKParser.RETURN_FO, 0)

        def Amplitude(self):
            return self.getToken(BarePKParser.Amplitude, 0)

        def Volume(self):
            return self.getToken(BarePKParser.Volume, 0)

        def Label(self):
            return self.getToken(BarePKParser.Label, 0)

        def Comment(self):
            return self.getToken(BarePKParser.Comment, 0)

        def peak_list_raw_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_2dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_rev_raw_format_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRev_raw_format_2d" ):
                listener.enterRev_raw_format_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRev_raw_format_2d" ):
                listener.exitRev_raw_format_2d(self)




    def rev_raw_format_2d(self):

        localctx = BarePKParser.Rev_raw_format_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 32, self.RULE_rev_raw_format_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 306
            self.match(BarePKParser.Peak)
            self.state = 307
            self.match(BarePKParser.Y_ppm)
            self.state = 308
            self.match(BarePKParser.X_ppm)
            self.state = 310
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==17:
                self.state = 309
                self.match(BarePKParser.Amplitude)


            self.state = 313
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==18:
                self.state = 312
                self.match(BarePKParser.Volume)


            self.state = 316
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==19:
                self.state = 315
                self.match(BarePKParser.Label)


            self.state = 319
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==20:
                self.state = 318
                self.match(BarePKParser.Comment)


            self.state = 321
            self.match(BarePKParser.RETURN_FO)
            self.state = 323 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 322
                    self.peak_list_raw_2d()

                else:
                    raise NoViableAltException(self)
                self.state = 325 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,34,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Rev_raw_format_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Peak(self):
            return self.getToken(BarePKParser.Peak, 0)

        def Z_ppm(self):
            return self.getToken(BarePKParser.Z_ppm, 0)

        def Y_ppm(self):
            return self.getToken(BarePKParser.Y_ppm, 0)

        def X_ppm(self):
            return self.getToken(BarePKParser.X_ppm, 0)

        def RETURN_FO(self):
            return self.getToken(BarePKParser.RETURN_FO, 0)

        def Amplitude(self):
            return self.getToken(BarePKParser.Amplitude, 0)

        def Volume(self):
            return self.getToken(BarePKParser.Volume, 0)

        def Label(self):
            return self.getToken(BarePKParser.Label, 0)

        def Comment(self):
            return self.getToken(BarePKParser.Comment, 0)

        def peak_list_raw_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_3dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_rev_raw_format_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRev_raw_format_3d" ):
                listener.enterRev_raw_format_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRev_raw_format_3d" ):
                listener.exitRev_raw_format_3d(self)




    def rev_raw_format_3d(self):

        localctx = BarePKParser.Rev_raw_format_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 34, self.RULE_rev_raw_format_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 327
            self.match(BarePKParser.Peak)
            self.state = 328
            self.match(BarePKParser.Z_ppm)
            self.state = 329
            self.match(BarePKParser.Y_ppm)
            self.state = 330
            self.match(BarePKParser.X_ppm)
            self.state = 332
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==17:
                self.state = 331
                self.match(BarePKParser.Amplitude)


            self.state = 335
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==18:
                self.state = 334
                self.match(BarePKParser.Volume)


            self.state = 338
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==19:
                self.state = 337
                self.match(BarePKParser.Label)


            self.state = 341
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==20:
                self.state = 340
                self.match(BarePKParser.Comment)


            self.state = 343
            self.match(BarePKParser.RETURN_FO)
            self.state = 345 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 344
                    self.peak_list_raw_3d()

                else:
                    raise NoViableAltException(self)
                self.state = 347 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,39,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Rev_raw_format_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Peak(self):
            return self.getToken(BarePKParser.Peak, 0)

        def A_ppm(self):
            return self.getToken(BarePKParser.A_ppm, 0)

        def Z_ppm(self):
            return self.getToken(BarePKParser.Z_ppm, 0)

        def Y_ppm(self):
            return self.getToken(BarePKParser.Y_ppm, 0)

        def X_ppm(self):
            return self.getToken(BarePKParser.X_ppm, 0)

        def RETURN_FO(self):
            return self.getToken(BarePKParser.RETURN_FO, 0)

        def Amplitude(self):
            return self.getToken(BarePKParser.Amplitude, 0)

        def Volume(self):
            return self.getToken(BarePKParser.Volume, 0)

        def Label(self):
            return self.getToken(BarePKParser.Label, 0)

        def Comment(self):
            return self.getToken(BarePKParser.Comment, 0)

        def peak_list_raw_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_4dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_rev_raw_format_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRev_raw_format_4d" ):
                listener.enterRev_raw_format_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRev_raw_format_4d" ):
                listener.exitRev_raw_format_4d(self)




    def rev_raw_format_4d(self):

        localctx = BarePKParser.Rev_raw_format_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 36, self.RULE_rev_raw_format_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 349
            self.match(BarePKParser.Peak)
            self.state = 350
            self.match(BarePKParser.A_ppm)
            self.state = 351
            self.match(BarePKParser.Z_ppm)
            self.state = 352
            self.match(BarePKParser.Y_ppm)
            self.state = 353
            self.match(BarePKParser.X_ppm)
            self.state = 355
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==17:
                self.state = 354
                self.match(BarePKParser.Amplitude)


            self.state = 358
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==18:
                self.state = 357
                self.match(BarePKParser.Volume)


            self.state = 361
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==19:
                self.state = 360
                self.match(BarePKParser.Label)


            self.state = 364
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            if _la==20:
                self.state = 363
                self.match(BarePKParser.Comment)


            self.state = 366
            self.match(BarePKParser.RETURN_FO)
            self.state = 368 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 367
                    self.peak_list_raw_4d()

                else:
                    raise NoViableAltException(self)
                self.state = 370 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,44,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Raw_format_wo_label_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_list_raw_2d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_2dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_2dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_raw_format_wo_label_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRaw_format_wo_label_2d" ):
                listener.enterRaw_format_wo_label_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRaw_format_wo_label_2d" ):
                listener.exitRaw_format_wo_label_2d(self)




    def raw_format_wo_label_2d(self):

        localctx = BarePKParser.Raw_format_wo_label_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 38, self.RULE_raw_format_wo_label_2d)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 373 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 372
                    self.peak_list_raw_2d()

                else:
                    raise NoViableAltException(self)
                self.state = 375 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,45,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Raw_format_wo_label_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_list_raw_3d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_3dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_3dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_raw_format_wo_label_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRaw_format_wo_label_3d" ):
                listener.enterRaw_format_wo_label_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRaw_format_wo_label_3d" ):
                listener.exitRaw_format_wo_label_3d(self)




    def raw_format_wo_label_3d(self):

        localctx = BarePKParser.Raw_format_wo_label_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 40, self.RULE_raw_format_wo_label_3d)
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 378 
            self._errHandler.sync(self)
            _alt = 1
            while _alt!=2 and _alt!=ATN.INVALID_ALT_NUMBER:
                if _alt == 1:
                    self.state = 377
                    self.peak_list_raw_3d()

                else:
                    raise NoViableAltException(self)
                self.state = 380 
                self._errHandler.sync(self)
                _alt = self._interp.adaptivePredict(self._input,46,self._ctx)

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Raw_format_wo_label_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def peak_list_raw_4d(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.Peak_list_raw_4dContext)
            else:
                return self.getTypedRuleContext(BarePKParser.Peak_list_raw_4dContext,i)


        def getRuleIndex(self):
            return BarePKParser.RULE_raw_format_wo_label_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterRaw_format_wo_label_4d" ):
                listener.enterRaw_format_wo_label_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitRaw_format_wo_label_4d" ):
                listener.exitRaw_format_wo_label_4d(self)




    def raw_format_wo_label_4d(self):

        localctx = BarePKParser.Raw_format_wo_label_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 42, self.RULE_raw_format_wo_label_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 383 
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while True:
                self.state = 382
                self.peak_list_raw_4d()
                self.state = 385 
                self._errHandler.sync(self)
                _la = self._input.LA(1)
                if not (_la==2):
                    break

        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_raw_2dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self):
            return self.getToken(BarePKParser.Integer, 0)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_raw_2d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_raw_2d" ):
                listener.enterPeak_list_raw_2d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_raw_2d" ):
                listener.exitPeak_list_raw_2d(self)




    def peak_list_raw_2d(self):

        localctx = BarePKParser.Peak_list_raw_2dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 44, self.RULE_peak_list_raw_2d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 387
            self.match(BarePKParser.Integer)
            self.state = 388
            self.position()
            self.state = 389
            self.position()
            self.state = 393
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 390
                self.number()
                self.state = 395
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 399
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==8:
                self.state = 396
                self.match(BarePKParser.Simple_name)
                self.state = 401
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 402
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_raw_3dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self):
            return self.getToken(BarePKParser.Integer, 0)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_raw_3d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_raw_3d" ):
                listener.enterPeak_list_raw_3d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_raw_3d" ):
                listener.exitPeak_list_raw_3d(self)




    def peak_list_raw_3d(self):

        localctx = BarePKParser.Peak_list_raw_3dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 46, self.RULE_peak_list_raw_3d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 404
            self.match(BarePKParser.Integer)
            self.state = 405
            self.position()
            self.state = 406
            self.position()
            self.state = 407
            self.position()
            self.state = 411
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 408
                self.number()
                self.state = 413
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 417
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==8:
                self.state = 414
                self.match(BarePKParser.Simple_name)
                self.state = 419
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 420
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class Peak_list_raw_4dContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Integer(self):
            return self.getToken(BarePKParser.Integer, 0)

        def position(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.PositionContext)
            else:
                return self.getTypedRuleContext(BarePKParser.PositionContext,i)


        def RETURN(self):
            return self.getToken(BarePKParser.RETURN, 0)

        def EOF(self):
            return self.getToken(BarePKParser.EOF, 0)

        def number(self, i:int=None):
            if i is None:
                return self.getTypedRuleContexts(BarePKParser.NumberContext)
            else:
                return self.getTypedRuleContext(BarePKParser.NumberContext,i)


        def Simple_name(self, i:int=None):
            if i is None:
                return self.getTokens(BarePKParser.Simple_name)
            else:
                return self.getToken(BarePKParser.Simple_name, i)

        def getRuleIndex(self):
            return BarePKParser.RULE_peak_list_raw_4d

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPeak_list_raw_4d" ):
                listener.enterPeak_list_raw_4d(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPeak_list_raw_4d" ):
                listener.exitPeak_list_raw_4d(self)




    def peak_list_raw_4d(self):

        localctx = BarePKParser.Peak_list_raw_4dContext(self, self._ctx, self.state)
        self.enterRule(localctx, 48, self.RULE_peak_list_raw_4d)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 422
            self.match(BarePKParser.Integer)
            self.state = 423
            self.position()
            self.state = 424
            self.position()
            self.state = 425
            self.position()
            self.state = 426
            self.position()
            self.state = 430
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while (((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0):
                self.state = 427
                self.number()
                self.state = 432
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 436
            self._errHandler.sync(self)
            _la = self._input.LA(1)
            while _la==8:
                self.state = 433
                self.match(BarePKParser.Simple_name)
                self.state = 438
                self._errHandler.sync(self)
                _la = self._input.LA(1)

            self.state = 439
            _la = self._input.LA(1)
            if not(_la==-1 or _la==10):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class PositionContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Float(self):
            return self.getToken(BarePKParser.Float, 0)

        def Integer(self):
            return self.getToken(BarePKParser.Integer, 0)

        def Ambig_float(self):
            return self.getToken(BarePKParser.Ambig_float, 0)

        def getRuleIndex(self):
            return BarePKParser.RULE_position

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterPosition" ):
                listener.enterPosition(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitPosition" ):
                listener.exitPosition(self)




    def position(self):

        localctx = BarePKParser.PositionContext(self, self._ctx, self.state)
        self.enterRule(localctx, 50, self.RULE_position)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 441
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & 44) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx


    class NumberContext(ParserRuleContext):
        __slots__ = 'parser'

        def __init__(self, parser, parent:ParserRuleContext=None, invokingState:int=-1):
            super().__init__(parent, invokingState)
            self.parser = parser

        def Float(self):
            return self.getToken(BarePKParser.Float, 0)

        def Real(self):
            return self.getToken(BarePKParser.Real, 0)

        def Integer(self):
            return self.getToken(BarePKParser.Integer, 0)

        def getRuleIndex(self):
            return BarePKParser.RULE_number

        def enterRule(self, listener:ParseTreeListener):
            if hasattr( listener, "enterNumber" ):
                listener.enterNumber(self)

        def exitRule(self, listener:ParseTreeListener):
            if hasattr( listener, "exitNumber" ):
                listener.exitNumber(self)




    def number(self):

        localctx = BarePKParser.NumberContext(self, self._ctx, self.state)
        self.enterRule(localctx, 52, self.RULE_number)
        self._la = 0 # Token type
        try:
            self.enterOuterAlt(localctx, 1)
            self.state = 443
            _la = self._input.LA(1)
            if not((((_la) & ~0x3f) == 0 and ((1 << _la) & 28) != 0)):
                self._errHandler.recoverInline(self)
            else:
                self._errHandler.reportMatch(self)
                self.consume()
        except RecognitionException as re:
            localctx.exception = re
            self._errHandler.reportError(self, re)
            self._errHandler.recover(self, re)
        finally:
            self.exitRule()
        return localctx





